//------------------------------------------------------------------------------
// Project    : Xilinx LogiCORE Virtex-6 Embedded Tri-Mode Ethernet MAC
// File       : v6_emac_v2_3_sgmii_mod.v
// Version    : 2.3
//-----------------------------------------------------------------------------
//
// (c) Copyright 2010-2011 Xilinx, Inc. All rights reserved.
//
// This file contains confidential and proprietary information
// of Xilinx, Inc. and is protected under U.S. and
// international copyright and other intellectual property
// laws.
//
// DISCLAIMER
// This disclaimer is not a license and does not grant any
// rights to the materials distributed herewith. Except as
// otherwise provided in a valid license issued to you by
// Xilinx, and to the maximum extent permitted by applicable
// law: (1) THESE MATERIALS ARE MADE AVAILABLE "AS IS" AND
// WITH ALL FAULTS, AND XILINX HEREBY DISCLAIMS ALL WARRANTIES
// AND CONDITIONS, EXPRESS, IMPLIED, OR STATUTORY, INCLUDING
// BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, NON-
// INFRINGEMENT, OR FITNESS FOR ANY PARTICULAR PURPOSE; and
// (2) Xilinx shall not be liable (whether in contract or tort,
// including negligence, or under any other theory of
// liability) for any loss or damage of any kind or nature
// related to, arising under or in connection with these
// materials, including for any direct, or any indirect,
// special, incidental, or consequential loss or damage
// (including loss of data, profits, goodwill, or any type of
// loss or damage suffered as a result of any action brought
// by a third party) even if such damage or loss was
// reasonably foreseeable or Xilinx had been advised of the
// possibility of the same.
//
// CRITICAL APPLICATIONS
// Xilinx products are not designed or intended to be fail-
// safe, or for use in any application requiring fail-safe
// performance, such as life-support or safety devices or
// systems, Class III medical devices, nuclear facilities,
// applications related to the deployment of airbags, or any
// other applications that could lead to death, personal
// injury, or severe property or environmental damage
// (individually and collectively, "Critical
// Applications"). Customer assumes the sole risk and
// liability of any use of Xilinx products in Critical
// Applications, subject only to applicable laws and
// regulations governing limitations on product liability.
//
// THIS COPYRIGHT NOTICE AND DISCLAIMER MUST BE RETAINED AS
// PART OF THIS FILE AT ALL TIMES.
//
// Description:  This is the Verilog module instantiation for the Virtex-6
//               Embedded Tri-Mode Ethernet MAC.
//
// ------------------------------------------------------------------------------

   module  v6_emac_v2_3_sgmii
   (

      //-------------------------------------------------------------------------
      // Clock signals - used in rgmii and serial modes
      //-------------------------------------------------------------------------
      input             gtx_clk,
      output            tx_axi_clk_out, // only in rgmii or sgmii

      //-------------------------------------------------------------------------
      // Receiver Interface.
      //-------------------------------------------------------------------------
      input             rx_axi_clk,
      output            rx_reset_out,
      output   [7:0]    rx_axis_mac_tdata,
      output            rx_axis_mac_tvalid,
      output            rx_axis_mac_tlast,
      output            rx_axis_mac_tuser,

      // RX sideband signals
      output   [27:0]   rx_statistics_vector,
      output            rx_statistics_valid,

      //-------------------------------------------------------------------------
      // Transmitter Interface
      //-------------------------------------------------------------------------
      input             tx_axi_clk,
      output            tx_reset_out,
      input    [7:0]    tx_axis_mac_tdata,
      input             tx_axis_mac_tvalid,
      input             tx_axis_mac_tlast,
      input             tx_axis_mac_tuser,
      output            tx_axis_mac_tready,

      // TX sideband signals
      output            tx_retransmit,
      output            tx_collision,
      input    [7:0]    tx_ifg_delay,
      output   [31:0]   tx_statistics_vector,
      output            tx_statistics_valid,

      //-------------------------------------------------------------------------
      // Flow Control
      //-------------------------------------------------------------------------
      input             pause_req,
      input    [15:0]   pause_val,

      //-------------------------------------------------------------------------
      // Speed interface
      //-------------------------------------------------------------------------
      output            speed_is_10_100,

      //-------------------------------------------------------------------------
      // GMII/MII Interface
      //-------------------------------------------------------------------------
      output   [7:0]    gmii_txd,
      input    [7:0]    gmii_rxd,
      input             gmii_rx_dv,

      //-------------------------------------------------------------------------
      // SGMII interface
      //-------------------------------------------------------------------------
      input             dcm_locked,
      output            an_interrupt,
      input             signal_det,
      input    [4:0]    phy_ad,
      output            en_comma_align,
      output            loopback_msb,
      output            mgt_rx_reset,
      output            mgt_tx_reset,
      output            powerdown,
      output            sync_acq_status,
      input    [2:0]    rx_clk_cor_cnt,
      input             rx_buf_status,
      input             rx_char_is_comma,
      input             rx_char_is_k,
      input             rx_disp_err,
      input             rx_not_in_table,
      input             rx_run_disp,
      input             tx_buf_err,
      output            tx_char_disp_mode,
      output            tx_char_disp_val,
      output            tx_char_is_k,

      //-------------------------------------------------------------------------
      // MDIO Interface
      //-------------------------------------------------------------------------
      input             mdc_in,
      input             mdio_in,
      output            mdio_out,
      output            mdio_tri,



      //-------------------------------------------------------------------------
      // Resets
      //-------------------------------------------------------------------------

      input             glbl_rstn,
      input             rx_axi_rstn,
      input             tx_axi_rstn

   );

endmodule
